@@ -21,13 +21,13 @@ import Data.Default (def)
 #endif
 -- import Data.Monoid              --
 import Data.List
+import Data.List.Extra (nubSort)
 import Data.Maybe
 -- import Data.Text (Text)
 import qualified Data.Text as T
 -- import Data.Time.Calendar
 import Graphics.Vty (mkVty)
 import Safe
-import System.Exit
 import System.Directory
 import System.FilePath
 import System.FSNotify
@@ -61,21 +61,18 @@ writeChan = BC.writeBChan
 
 main :: IO ()
 main = do
-  opts <- getHledgerUIOpts
-  let copts = cliopts_ opts
-      copts' = copts
-        { inputopts_ = (inputopts_ copts) { auto_ = True }
-        , reportopts_ = (reportopts_ copts) { forecast_ = True }
-        }
-
+  opts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=ropts,rawopts_=rawopts}} <- getHledgerUIOpts
   -- when (debug_ $ cliopts_ opts) $ printf "%s\n" prognameandversion >> printf "opts: %s\n" (show opts)
-  run $ opts { cliopts_ = copts' }
-    where
-      run opts
-        | "help"            `inRawOpts` (rawopts_ $ cliopts_ opts) = putStr (showModeUsage uimode) >> exitSuccess
-        | "version"         `inRawOpts` (rawopts_ $ cliopts_ opts) = putStrLn prognameandversion >> exitSuccess
-        | "binary-filename" `inRawOpts` (rawopts_ $ cliopts_ opts) = putStrLn (binaryfilename progname)
-        | otherwise                                                = withJournalDo (cliopts_ opts) (runBrickUi opts)
+
+  -- always include forecasted periodic transactions when loading data;
+  -- they will be toggled on and off in the UI.
+  let copts' = copts{reportopts_=ropts{forecast_=Just $ fromMaybe nulldatespan (forecast_ ropts)}}
+
+  case True of
+    _ | "help"            `inRawOpts` rawopts -> putStr (showModeUsage uimode)
+    _ | "version"         `inRawOpts` rawopts -> putStrLn prognameandversion
+    _ | "binary-filename" `inRawOpts` rawopts -> putStrLn (binaryfilename progname)
+    _                                         -> withJournalDo copts' (runBrickUi opts)
 
 runBrickUi :: UIOpts -> Journal -> IO ()
 runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=ropts}} j = do
@@ -205,7 +202,7 @@ runBrickUi uopts@UIOpts{cliopts_=copts@CliOpts{inputopts_=_iopts,reportopts_=rop
       withManager $ \mgr -> do
         dbg1IO "fsnotify using polling ?" $ isPollingManager mgr
         files <- mapM (canonicalizePath . fst) $ jfiles j
-        let directories = nub $ sort $ map takeDirectory files
+        let directories = nubSort $ map takeDirectory files
         dbg1IO "files" files
         dbg1IO "directories to watch" directories
 
