@@ -45,7 +45,7 @@ transactionScreen = TransactionScreen{
 tsInit :: Day -> Bool -> UIState -> UIState
 tsInit _d _reset ui@UIState{aopts=UIOpts{cliopts_=CliOpts{reportopts_=_ropts}}
                            ,ajournal=_j
-                           ,aScreen=TransactionScreen{..}
+                           ,aScreen=TransactionScreen{}
                            } =
   -- plog ("initialising TransactionScreen, value_ is "
   --       -- ++ (pshow (Just (AtDefault Nothing)::Maybe ValuationType))
@@ -73,7 +73,7 @@ tsDraw UIState{aopts=UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}
   where
     maincontent = Widget Greedy Greedy $ do
       let
-        prices = journalPriceOracle j
+        prices = journalPriceOracle (infer_value_ ropts) j
         styles = journalCommodityStyles j
         periodlast =
           fromMaybe (error' "TransactionScreen: expected a non-empty journal") $ -- XXX shouldn't happen
