@@ -14,6 +14,7 @@ import Brick.Widgets.Edit
 import Data.List
 import Data.Text.Zipper (gotoEOL)
 import Data.Time.Calendar (Day)
+import Data.Maybe (fromMaybe)
 
 import Hledger
 import Hledger.Cli.CliOptions
@@ -151,13 +152,28 @@ toggleHistorical ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts
     b | balancetype_ ropts == HistoricalBalance = PeriodChange
       | otherwise                               = HistoricalBalance
 
--- | Toggle between including and excluding transactions dated later than today.
-toggleFuture :: UIState -> UIState
-toggleFuture ui@UIState{aopts=uopts@UIOpts{presentorfuture_=pf}} =
-  ui{aopts=uopts{presentorfuture_=pf'}}
+-- | Toggle hledger-ui's "forecast mode". In forecast mode, periodic
+-- transactions (generated by periodic rules) are enabled (as with
+-- hledger --forecast), and also future transactions in general
+-- (including non-periodic ones) are displayed. In normal mode, all
+-- future transactions (periodic or not) are suppressed (unlike
+-- command-line hledger).
+--
+-- After toggling this, we do a full reload of the journal from disk
+-- to make it take effect; currently that's done in the callers (cf
+-- AccountsScreen, RegisterScreen) where it's easier. This is
+-- overkill, probably we should just hide/show the periodic
+-- transactions with a query for their special tag.
+--
+toggleForecast :: Day -> UIState -> UIState
+toggleForecast d ui@UIState{aopts=uopts@UIOpts{cliopts_=copts@CliOpts{reportopts_=ropts}}} =
+  ui{aopts=uopts{cliopts_=copts'}}
   where
-    pf' | pf == PFFuture = PFPresent
-        | otherwise      = PFFuture
+    copts' = copts{reportopts_=ropts{forecast_=forecast'}}
+    forecast' =
+      case forecast_ ropts of
+        Just _  -> Nothing
+        Nothing -> Just $ fromMaybe nulldatespan $ forecastPeriodFromRawOpts d $ rawopts_ copts
 
 -- | Toggle between showing all and showing only real (non-virtual) items.
 toggleReal :: UIState -> UIState
