@@ -40,7 +40,7 @@ module Hledger.UI.UITypes where
 
 import Data.Time.Calendar (Day)
 import Brick
-import Brick.Widgets.List hiding (reverse)
+import Brick.Widgets.List (List)
 import Brick.Widgets.Edit (Editor)
 import Lens.Micro.Platform
 import Text.Show.Functions ()
